@@ -4,7 +4,8 @@
 require(PBSddesolve)
 if (!require(PBSmodelling)) stop("The package PBSmodelling must be installed for this demo")
 
-#close any existing windows
+local(env=.PBSddeEnv, expr={
+
 closeWin("window")
 
 #store working directory
@@ -18,7 +19,7 @@ runPlot <- function() {
 	getWinVal(scope="L")
 	
 	# `y' is the estimated value of the variable at time `t'
-	# y[1] represents the tempurature of a cup of coffee at a given time `t'.
+	# y[1] represents the temperature of a cup of coffee at a given time `t'.
 	# dy/dt ~ y - room tempurature. 
 	# so we can write dy/dt = -rho(y - roomTemp)
 	myGrad <- function(t, y) {
@@ -32,6 +33,8 @@ runPlot <- function() {
 }
 
 #restore working directory once demo is done
-onClose <- function() { setwd(oldwd); }
+#onClose <- function() { setwd(oldwd); }
+# Now handled by `.onClosePBSddeExamples`
 
-createWin("demo_files/cooling_win.txt")
\ No newline at end of file
+createWin("demo_files/cooling_win.txt")
+})
